==> vue3-components-0.2.28.tgz: package/es/table/src/table.js <==
import { defineComponent as ie, ref as r, onMounted as A, withDirectives as ne, createVNode as o, mergeProps as G, resolveDirective as ue, unref as oe, toRef as N, resolveComponent as H, Fragment as re, nextTick as _, isVNode as de } from "vue";
import ce from "qs";
import "../../selectArea/index.js";
import "../../selectDate/index.js";
import "../../selectTime/index.js";
import "../../trend/index.js";
import "../../progress/index.js";
import "../../notification/index.js";
import "../index.js";
import { KCustomElement as B } from "../../customElement/index.js";
import "../../form/index.js";
import { tableProps as me, tableEmits as ve } from "./props.js";
import { Check as se, Close as fe, Edit as ge } from "@element-plus/icons-vue";
import { createNamespacs as he, getI18nKey as we, getValue as W } from "@tomiaa/utils";
import "../../node_modules/.pnpm/@tomiaa_theme-chalk@0.0.4/node_modules/@tomiaa/theme-chalk/lib/vue3-components/table.css.js";
import { useI18n as Te } from "vue-i18n";
import { vLoading as ye, ElTable as Pe, ElIcon as xe, ElTableColumn as Ee, ElPagination as be } from "element-plus";
import "../../node_modules/.pnpm/element-plus@2.2.26_vue@3.2.45/node_modules/element-plus/theme-chalk/el-table.css.js";
import "../../node_modules/.pnpm/element-plus@2.2.26_vue@3.2.45/node_modules/element-plus/theme-chalk/el-pagination.css.js";
function ze(e) {
  return typeof e == "function" || Object.prototype.toString.call(e) === "[object Object]" && !de(e);
}
const y = he("table"), Je = ie({
  name: "KTable",
  directives: {
    loading: ye
  },
  props: me,
  emits: ve,
  setup(e, {
    attrs: C,
    slots: P,
    emit: s,
    expose: X
  }) {
    const {
      t: Y
    } = Te(), L = r(""), Q = r(""), {
      append: Z,
      empty: p = () => e.emptyTip && x.value && L.value,
      page: ee,
      editControlIcon: j,
      editIcon: U
    } = P, f = r({}), h = r({}), te = (c) => c == null ? void 0 : c.map((g) => {
      const E = {};
      for (const a in g)
        E[a] = oe(g[a]);
      for (const a in g) {
        const z = we(g[a]);
        z && (E[a] = Y(z));
      }
      const {
        slot: b,
        action: w,
        actionConfig: t,
        editable: k,
        editableConfig: u,
        ...D
      } = E, l = r({}), v = r({}), T = {
        header: P.header,
        default(a) {
          var z, $;
          if (b)
            return (z = P[b]) == null ? void 0 : z.call(P, a);
          if (w || t) {
            const {
              $index: i,
              row: m
            } = a;
            let d = [{
              el: "el-button",
              size: "small",
              "v-if": typeof (t == null ? void 0 : t.showEdit) < "u" ? t == null ? void 0 : t.showEdit : e.actionConfig.showEdit,
              onClick: () => {
                if (e.editRow) {
                  if (f.value[i]) {
                    Object.assign(a.row, h.value[i]), delete h.value[i], delete f.value[i], s("confirmEditRow", a);
                    return;
                  }
                  h.value[i] = JSON.parse(JSON.stringify(m)), f.value[i] = !0;
                }
                s("edit", a);
              },
              children: f.value[i] ? (t == null ? void 0 : t.editRowEnterText) || e.actionConfig.editRowEnterText || "确定" : (t == null ? void 0 : t.editText) || e.actionConfig.editText || "编辑"
            }, {
              el: "el-button",
              size: "small",
              type: "danger",
              "v-if": typeof (t == null ? void 0 : t.showDelete) < "u" ? t == null ? void 0 : t.showDelete : e.actionConfig.showDelete,
              onClick: () => {
                if (e.editRow) {
                  delete h.value[i], delete f.value[i], s("cancelEditRow", a);
                  return;
                }
                s("delete", a);
              },
              children: f.value[i] ? (t == null ? void 0 : t.editRowCloseText) || e.actionConfig.editRowCloseText || "取消" : (t == null ? void 0 : t.deleteText) || (($ = e.actionConfig) == null ? void 0 : $.deleteText) || "删除"
            }];
            return e.actionConfig.custom && (d = e.actionConfig.custom(d, a)), t != null && t.custom && (d = t.custom(d, a)), o(B, {
              list: d
            }, null);
          }
          if (k || u) {
            const {
              row: i,
              column: m,
              $index: d
            } = a, n = m.id + d, J = () => {
              delete v.value[n], delete l.value[n];
            };
            let V = [{
              el: "el-icon",
              color: "var(--el-color-success)",
              size: "1.2em",
              "v-if": u == null ? void 0 : u.showEnter,
              onClick() {
                i[m.property] = v.value[n], J(), s("confirmEditCell", a);
              },
              children: se
            }, {
              el: "el-icon",
              size: "1.2em",
              color: "var(--el-color-danger)",
              "v-if": u == null ? void 0 : u.showClose,
              onClick() {
                J(), s("cancelEditCell", a);
              },
              children: fe
            }];
            return u != null && u.custom && (V = u.custom(V, a, N(l.value, n))), o("div", {
              class: [y.e("editable"), y.is("editable", l.value[n])]
            }, [l.value[n] ? o(H("el-input"), {
              size: "small",
              modelValue: v.value[n],
              "onUpdate:modelValue": (le) => v.value[n] = le
            }, null) : i[m.property], l.value[n] ? o(re, null, [
              (j == null ? void 0 : j({
                ...a,
                isEdit: N(l.value, n)
              })) || o(B, {
                list: V
              }, null)
            ]) : U ? o("span", {
              onClick: () => {
                v.value[n] = i[m.property];
              }
            }, [U({
              ...a,
              isEdit: N(l.value, n)
            })]) : o(xe, {
              size: "1.2em",
              onClick: () => {
                v.value[n] = i[m.property], l.value[n] = !l.value[n];
              }
            }, {
              default: () => [o(ge, null, null)]
            })]);
          }
          if (e.editRow) {
            const {
              row: i,
              column: m,
              $index: d
            } = a;
            return o("div", {
              class: [y.e("editable"), y.is("editable", f.value[d])]
            }, [f.value[d] ? o(H("el-input"), {
              size: "small",
              modelValue: h.value[d][m.property],
              "onUpdate:modelValue": (n) => h.value[d][m.property] = n
            }, null) : i[m.property]]);
          }
        }
      };
      return o(Ee, D, ze(T) ? T : {
        default: () => [T]
      });
    }), ae = () => o(be, G({
      class: y.b("pagination"),
      defaultCurrentPage: e.defaultCurrentPage,
      defaultPageSize: e.defaultPageSize,
      currentPage: K.value,
      pageSize: M.value,
      total: F.value,
      ref: R,
      layout: "->,sizes,prev,pager,next,jumper,total",
      "hide-on-single-page": !0
    }, C, {
      "onUpdate:current-page": async (c) => {
        K.value = c, await _(), S();
      },
      "onUpdate:page-size": async (c) => {
        M.value = c, await _(), S();
      }
    }), {
      default: ee
    }), R = r(), q = r(), I = r(null), F = r(0), K = r(e.defaultCurrentPage || 1), M = r(e.defaultPageSize || 10), x = r(!1), S = () => {
      var k, u, D;
      x.value = !0, I.value = null;
      let c;
      e.emptyTip && (L.value = e.emptyTip, clearTimeout(c), c = setTimeout(() => {
        L.value = e.emptyTipTimeoutText;
      }, e.emptyTipTimeout));
      let g;
      e.elLoadingTextTimeoutText && (Q.value = e.elementLoadingText, clearTimeout(g), setTimeout(() => {
        const l = document.querySelector(".el-loading-text");
        l && (l.innerHTML = e.elLoadingTextTimeoutText);
      }, e.elLoadingTextTimeout));
      const E = e.server, b = {
        [((k = e.replaceFields) == null ? void 0 : k.pageSize) || "pageSize"]: R.value.pageSize,
        [((u = e.replaceFields) == null ? void 0 : u.currentPage) || "currentPage"]: R.value.currentPage
      }, w = {};
      if (e.withDataPath !== !1) {
        const l = {
          get: "params",
          post: "data"
        }, v = e.withDataPath || l[(((D = e.getConfig) == null ? void 0 : D.method) || "get").toLocaleLowerCase()];
        v && (w[v] = {});
        const T = w[v] || w;
        Object.assign(T, e.withPagePath && typeof e.withPagePath == "string" ? {
          [e.withPagePath]: b
        } : b), Object.assign(T, e.withQueryPath && typeof e.withQueryPath == "string" ? {
          [e.withQueryPath]: e.withQuery
        } : e.withQuery);
      }
      const t = {
        url: e.getUrl,
        ...w,
        ...e.getConfig
      };
      e.stringify && t.data && (t.data = ce.stringify(t.data)), s("beforeGetData", t), E(t).then((l) => {
        s("afterGetData", l), I.value = W(e.dataPath, l), F.value = W(e.totalPath, l);
      }).catch((l) => {
        s("failToGetData", l);
      }).finally(() => {
        clearTimeout(c), clearTimeout(g), x.value = !1;
      });
    };
    e.showPagination && A(S);
    const O = {
      getData: S
    };
    return A(() => {
      O.elPagination = R.value, O.elTable = q.value;
    }), X(O), () => ne(o("div", G({
      class: y.b(),
      "element-loading-text": Q.value
    }, C), [o(Pe, G({
      data: I.value,
      ref: q
    }, C), {
      default: () => [te(e.options)],
      append: Z,
      empty: p
    }), e.showPagination && ae(), e.showLoadInGet && x.value]), [[ue("loading"), e.showLoadInGet && x.value]]);
  }
});
export {
  Je as default
};

==> vue3-components-0.2.30.tgz: package/es/table/src/table.js <==
import { defineComponent as ie, ref as r, onMounted as A, withDirectives as ne, createVNode as o, mergeProps as G, resolveDirective as ue, unref as oe, toRef as N, resolveComponent as H, Fragment as re, nextTick as _, isVNode as de } from "vue";
import ce from "qs";
import "../../selectArea/index.js";
import "../../selectDate/index.js";
import "../../selectTime/index.js";
import "../../trend/index.js";
import "../../progress/index.js";
import "../../notification/index.js";
import "../index.js";
import { KCustomElement as B } from "../../customElement/index.js";
import "../../form/index.js";
import { tableProps as me, tableEmits as ve } from "./props.js";
import { Check as se, Close as fe, Edit as ge } from "@element-plus/icons-vue";
import { createNamespacs as he, getI18nKey as we, getValue as W } from "@tomiaa/utils";
import "../../node_modules/.pnpm/@tomiaa_theme-chalk@0.0.5/node_modules/@tomiaa/theme-chalk/lib/vue3-components/table.css.js";
import { useI18n as Te } from "vue-i18n";
import { vLoading as ye, ElTable as Pe, ElIcon as xe, ElTableColumn as Ee, ElPagination as be } from "element-plus";
import "../../node_modules/.pnpm/element-plus@2.2.30_vue@3.2.47/node_modules/element-plus/theme-chalk/el-table.css.js";
import "../../node_modules/.pnpm/element-plus@2.2.30_vue@3.2.47/node_modules/element-plus/theme-chalk/el-pagination.css.js";
function ze(e) {
  return typeof e == "function" || Object.prototype.toString.call(e) === "[object Object]" && !de(e);
}
const y = he("table"), Je = /* @__PURE__ */ ie({
  name: "KTable",
  directives: {
    loading: ye
  },
  props: me,
  emits: ve,
  setup(e, {
    attrs: C,
    slots: P,
    emit: s,
    expose: X
  }) {
    const {
      t: Y
    } = Te(), L = r(""), Q = r(""), {
      append: Z,
      // 自动获取数据时显示文字提示，而不是空状态
      empty: p = () => e.emptyTip && x.value && L.value,
      page: ee,
      // 分页插槽
      editControlIcon: j,
      // 编辑确认取消插槽
      editIcon: U
      // 单元格编辑按钮插槽
    } = P, f = r({}), h = r({}), te = (c) => c == null ? void 0 : c.map((g) => {
      const E = {};
      for (const a in g)
        E[a] = oe(g[a]);
      for (const a in g) {
        const z = we(g[a]);
        z && (E[a] = Y(z));
      }
      const {
        // 取出自定义的属性
        slot: b,
        // 插槽名
        action: w,
        // 操作栏
        actionConfig: t,
        // 操作栏配置
        editable: k,
        // 单元格编辑
        editableConfig: u,
        // 单元格内编辑配置
        // 剩余的就是 element-column 的属性
        ...D
      } = E, l = r({}), v = r({}), T = {
        header: P.header,
        // 表头
        default(a) {
          var z, $;
          if (b)
            return (z = P[b]) == null ? void 0 : z.call(P, a);
          if (w || t) {
            const {
              $index: i,
              row: m
            } = a;
            let d = [{
              el: "el-button",
              size: "small",
              "v-if": typeof (t == null ? void 0 : t.showEdit) < "u" ? t == null ? void 0 : t.showEdit : e.actionConfig.showEdit,
              onClick: () => {
                if (e.editRow) {
                  if (f.value[i]) {
                    Object.assign(a.row, h.value[i]), delete h.value[i], delete f.value[i], s("confirmEditRow", a);
                    return;
                  }
                  h.value[i] = JSON.parse(JSON.stringify(m)), f.value[i] = !0;
                }
                s("edit", a);
              },
              children: f.value[i] ? (t == null ? void 0 : t.editRowEnterText) || e.actionConfig.editRowEnterText || "确定" : (t == null ? void 0 : t.editText) || e.actionConfig.editText || "编辑"
            }, {
              el: "el-button",
              size: "small",
              type: "danger",
              "v-if": typeof (t == null ? void 0 : t.showDelete) < "u" ? t == null ? void 0 : t.showDelete : e.actionConfig.showDelete,
              onClick: () => {
                if (e.editRow) {
                  delete h.value[i], delete f.value[i], s("cancelEditRow", a);
                  return;
                }
                s("delete", a);
              },
              children: f.value[i] ? (t == null ? void 0 : t.editRowCloseText) || e.actionConfig.editRowCloseText || "取消" : (t == null ? void 0 : t.deleteText) || (($ = e.actionConfig) == null ? void 0 : $.deleteText) || "删除"
            }];
            return e.actionConfig.custom && (d = e.actionConfig.custom(d, a)), t != null && t.custom && (d = t.custom(d, a)), o(B, {
              list: d
            }, null);
          }
          if (k || u) {
            const {
              row: i,
              column: m,
              $index: d
            } = a, n = m.id + d, J = () => {
              delete v.value[n], delete l.value[n];
            };
            let V = [{
              el: "el-icon",
              color: "var(--el-color-success)",
              size: "1.2em",
              "v-if": u == null ? void 0 : u.showEnter,
              onClick() {
                i[m.property] = v.value[n], J(), s("confirmEditCell", a);
              },
              children: se
            }, {
              el: "el-icon",
              size: "1.2em",
              color: "var(--el-color-danger)",
              "v-if": u == null ? void 0 : u.showClose,
              onClick() {
                J(), s("cancelEditCell", a);
              },
              children: fe
            }];
            return u != null && u.custom && (V = u.custom(V, a, N(l.value, n))), o("div", {
              class: [y.e("editable"), y.is("editable", l.value[n])]
            }, [l.value[n] ? (
              // 编辑单元格时-输入框
              o(H("el-input"), {
                size: "small",
                modelValue: v.value[n],
                "onUpdate:modelValue": (le) => v.value[n] = le
              }, null)
            ) : (
              // 没有编辑时
              i[m.property]
            ), l.value[n] ? o(re, null, [
              // 编辑确认取消按钮
              (j == null ? void 0 : j({
                ...a,
                isEdit: N(l.value, n)
              })) || o(B, {
                list: V
              }, null)
            ]) : (
              // 编辑图标
              U ? o("span", {
                onClick: () => {
                  v.value[n] = i[m.property];
                }
              }, [U({
                ...a,
                isEdit: N(l.value, n)
              })]) : o(xe, {
                size: "1.2em",
                onClick: () => {
                  v.value[n] = i[m.property], l.value[n] = !l.value[n];
                }
              }, {
                default: () => [o(ge, null, null)]
              })
            )]);
          }
          if (e.editRow) {
            const {
              row: i,
              column: m,
              $index: d
            } = a;
            return o("div", {
              class: [y.e("editable"), y.is("editable", f.value[d])]
            }, [f.value[d] ? (
              // 编辑单元格时-输入框
              o(H("el-input"), {
                size: "small",
                modelValue: h.value[d][m.property],
                "onUpdate:modelValue": (n) => h.value[d][m.property] = n
              }, null)
            ) : (
              // 没有编辑时
              i[m.property]
            )]);
          }
        }
      };
      return o(Ee, D, ze(T) ? T : {
        default: () => [T]
      });
    }), ae = () => o(be, G({
      class: y.b("pagination"),
      defaultCurrentPage: e.defaultCurrentPage,
      defaultPageSize: e.defaultPageSize,
      currentPage: K.value,
      pageSize: M.value,
      total: F.value,
      ref: R,
      layout: "->,sizes,prev,pager,next,jumper,total",
      "hide-on-single-page": !0
    }, C, {
      "onUpdate:current-page": async (c) => {
        K.value = c, await _(), S();
      },
      "onUpdate:page-size": async (c) => {
        M.value = c, await _(), S();
      }
    }), {
      default: ee
    }), R = r(), q = r(), I = r(null), F = r(0), K = r(e.defaultCurrentPage || 1), M = r(e.defaultPageSize || 10), x = r(!1), S = () => {
      var k, u, D;
      x.value = !0, I.value = null;
      let c;
      e.emptyTip && (L.value = e.emptyTip, clearTimeout(c), c = setTimeout(() => {
        L.value = e.emptyTipTimeoutText;
      }, e.emptyTipTimeout));
      let g;
      e.elLoadingTextTimeoutText && (Q.value = e.elementLoadingText, clearTimeout(g), setTimeout(() => {
        const l = document.querySelector(".el-loading-text");
        l && (l.innerHTML = e.elLoadingTextTimeoutText);
      }, e.elLoadingTextTimeout));
      const E = e.server, b = {
        [((k = e.replaceFields) == null ? void 0 : k.pageSize) || "pageSize"]: R.value.pageSize,
        [((u = e.replaceFields) == null ? void 0 : u.currentPage) || "currentPage"]: R.value.currentPage
      }, w = {};
      if (e.withDataPath !== !1) {
        const l = {
          get: "params",
          post: "data"
        }, v = e.withDataPath || l[(((D = e.getConfig) == null ? void 0 : D.method) || "get").toLocaleLowerCase()];
        v && (w[v] = {});
        const T = w[v] || w;
        Object.assign(T, e.withPagePath && typeof e.withPagePath == "string" ? {
          [e.withPagePath]: b
        } : b), Object.assign(T, e.withQueryPath && typeof e.withQueryPath == "string" ? {
          [e.withQueryPath]: e.withQuery
        } : e.withQuery);
      }
      const t = {
        url: e.getUrl,
        ...w,
        ...e.getConfig
      };
      e.stringify && t.data && (t.data = ce.stringify(t.data)), s("beforeGetData", t), E(t).then((l) => {
        s("afterGetData", l), I.value = W(e.dataPath, l), F.value = W(e.totalPath, l);
      }).catch((l) => {
        s("failToGetData", l);
      }).finally(() => {
        clearTimeout(c), clearTimeout(g), x.value = !1;
      });
    };
    e.showPagination && A(S);
    const O = {
      getData: S
    };
    return A(() => {
      O.elPagination = R.value, O.elTable = q.value;
    }), X(O), () => ne(o("div", G({
      class: y.b(),
      "element-loading-text": Q.value
    }, C), [o(Pe, G({
      data: I.value,
      ref: q
    }, C), {
      default: () => [te(e.options)],
      append: Z,
      empty: p
    }), e.showPagination && ae(), e.showLoadInGet && x.value]), [[ue("loading"), e.showLoadInGet && x.value]]);
  }
});
export {
  Je as default
};
